aeon provides an easy-to-use, flexible and modular `open-source
<https://github.com/aeon-toolkit/aeon/blob/main/LICENSE>`_ :term:`framework` for a wide range of time series machine learning tasks.
It offers `scikit-learn <http://scikit-learn.org>`_ compatible interfaces and model composition tools, with the goal to make the ecosystem more usable and interoperable as a whole.
We build and sustain an open, diverse and :ref:`self-governing <governance>` community, welcoming new contributors from academia and industry through instructive documentation, :ref:`mentoring <mentoring>` and :ref:`workshops <meetups>`.
